Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Done ¶
func Done()
Done changes the mode to one where no action is taken, and any input closes the program.
func PrintPath ¶
func PrintPath(pre, path, post string)
PrintPath adds a line to the display, with a middle path segment that is truncated at the left rather than the right.
func Printf ¶
func Printf(format string, a ...interface{})
Printf adds a line to the display, formatted by fmt.Sprintf.
func Prompt ¶
Prompt prints the given string and blocks until the user inputs one of the alphanumeric characters shown in parentheses. For example, a prompt containing "(y/n)" would accept either 'y' or 'n' as input. Multiple parentheticals can be included.
func PromptSeed ¶
PromptSeed waits for the user to input 8 hex digits, then returns the string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.